.. image:: https://travis-ci.org/galaxyproject/bioblend.png
        :target: https://travis-ci.org/galaxyproject/bioblend

.. image:: https://pypip.in/d/bioblend/badge.png
        :target: https://pypi.python.org/pypi/bioblend/

.. image:: https://landscape.io/github/galaxyproject/bioblend/master/landscape.svg?style=flat
        :target: https://landscape.io/github/galaxyproject/bioblend/master
        :alt: Code Health


BioBlend is a Python (2.6 or 2.7) library for interacting with `CloudMan`_
and `Galaxy`_'s API.

BioBlend is supported and tested on Galaxy release_14.02 and later.

Full docs are available at http://bioblend.readthedocs.org with a quick library
overview also available in `ABOUT.rst <./ABOUT.rst>`_.

.. References/hyperlinks used above
.. _CloudMan: http://usecloudman.org/
.. _Galaxy: http://usegalaxy.org/
